# Onyx

A documentation theme forked from [Hugo Alabaster
theme](https://github.com/digitalcraftsman/hugo-alabaster-theme). It is an
indirect port of [Sphinx](http://www.sphinx-doc.org/en/stable/).

## Theme components
This theme is composed of the base theme "hugo-onyx-theme", and
the "hugo-search-fuse-js" component.

To use this theme, you need to clone this theme and the component(s) too:
```shell
cd HUGO_SITE_DIR/themes
git clone https://github.com/kaushalmodi/hugo-onyx-theme
git clone https://github.com/kaushalmodi/hugo-search-fuse-js
```

**Do not change the cloned repo directory names.**

## Alabaster screenshot

[![Screenshot](https://raw.githubusercontent.com/digitalcraftsman/hugo-alabaster-theme/dev/images/screenshot.png)](https://digitalcraftsman.github.io/hugo-alabaster-theme/)

## Quick start

Install with `git`:

```sh
cd /to/your/hugo/site/repo/root
git clone https://github.com/kaushalmodi/hugo-onyx-theme themes/hugo-onyx-theme
```

Next, take a look in the `exampleSite` folder at. This directory contains an
example config file and the content for the demo. It serves as an example setup
for your documentation.

Copy at least the `config.toml` in the root directory of your website. Overwrite
the existing config file if necessary.

Hugo includes a development server, so you can view your changes as you go -
very handy. Spin it up with the following command:

``` sh
hugo server
```

Now you can go to `localhost:1313` and the Onyx theme generated site should be
visible.

[**Demo**][demo]

## Acknowledgements

I want to give a big shout-out to
[Digitalcraftsman](https://github.com/digitalcraftsman), and also to the
original theme (from which the Alabaster theme was ported) authors [Jeff
Forcier](https://github.com/bitprophet), [Kenneth
Reitz](https://github.com/kennethreitz) and [Armin
Ronacher](https://github.com/mitsuhiko).

Furthermore, thanks to [Steve Francia](https://github.com/spf13) for creating
Hugo, [Bjørn Erik Pedersen](https://github.com/bep) for leading the current Hugo
development, and the [awesome
community](https://github.com/spf13/hugo/graphs/contributors) around the
project.


## License

The theme is released under the BSD license. Read the
[license](https://github.com/kaushalmodi/hugo-onyx-theme/blob/master/LICENSE.md)
for more information.

[demo]: https://hugo-onyx.netlify.com/
